==> apache-cassandra-3.0.25-src.tar.gz: apache-cassandra-3.0.25-src/src/java/org/apache/cassandra/transport/messages/ReadyMessage.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.cassandra.transport.messages;

import io.netty.buffer.ByteBuf;

import org.apache.cassandra.transport.Message;

/**
 * Message to indicate that the server is ready to receive requests.
 */
public class ReadyMessage extends Message.Response
{
    public static final Message.Codec<ReadyMessage> codec = new Message.Codec<ReadyMessage>()
    {
        public ReadyMessage decode(ByteBuf body, int version)
        {
            return new ReadyMessage();
        }

        public void encode(ReadyMessage msg, ByteBuf dest, int version)
        {
        }

        public int encodedSize(ReadyMessage msg, int version)
        {
            return 0;
        }
    };

    public ReadyMessage()
    {
        super(Message.Type.READY);
    }

    @Override
    public String toString()
    {
        return "READY";
    }
}

==> apache-cassandra-4.1.10-src.tar.gz: apache-cassandra-4.1.10-src/src/java/org/apache/cassandra/transport/messages/ReadyMessage.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.cassandra.transport.messages;

import io.netty.buffer.ByteBuf;

import org.apache.cassandra.transport.Message;
import org.apache.cassandra.transport.ProtocolVersion;

/**
 * Message to indicate that the server is ready to receive requests.
 */
public class ReadyMessage extends Message.Response
{
    public static final Message.Codec<ReadyMessage> codec = new Message.Codec<ReadyMessage>()
    {
        public ReadyMessage decode(ByteBuf body, ProtocolVersion version)
        {
            return new ReadyMessage();
        }

        public void encode(ReadyMessage msg, ByteBuf dest, ProtocolVersion version)
        {
        }

        public int encodedSize(ReadyMessage msg, ProtocolVersion version)
        {
            return 0;
        }
    };

    public ReadyMessage()
    {
        super(Message.Type.READY);
    }

    @Override
    public String toString()
    {
        return "READY";
    }
}
